"""
Constants having to do with date or time

.. data:: MINUTE_IN_SECONDS

.. data:: HOUR_IN_SECONDS

.. data:: DAY_IN_SECONDS

.. data:: WEEK_IN_SECONDS

.. data:: MONTH_IN_SECONDS

.. data:: YEAR_IN_SECONDS

"""

MINUTE_IN_SECONDS: int = 60

HOUR_IN_SECONDS: int = MINUTE_IN_SECONDS * 60

DAY_IN_SECONDS: int = HOUR_IN_SECONDS * 24

WEEK_IN_SECONDS: int = DAY_IN_SECONDS * 7

MONTH_IN_SECONDS: int = WEEK_IN_SECONDS * 4

YEAR_IN_SECONDS: int = WEEK_IN_SECONDS * 52



import typer
import pytest
from pytest import ExitCode
import os
from pathlib import Path
import coverage

cli = typer.Typer()


# https://docs.pytest.org/en/documentation-restructure/how-to/writing_plugins.html#well-specified-hooks
class eHelplyPytest:
    pass
    # def pytest_sessionfinish(self):
    #     print("", "*** starting coverage report ***")


COVERAGE_THRESHOLD: int = 85


@cli.command()
def units(

):
    root_path = Path(os.getcwd())

    docs_location = Path(root_path).resolve().joinpath('test-results')
    docs_location.mkdir(exist_ok=True)

    result: ExitCode = pytest.main(
        [
            "-s",
            "-v",
            # "--cov-report", "term-missing",
            "--cov-report", f"html:{str(docs_location)}",
            "--cov=src",
            "tests/"
        ]
    )

    if result != ExitCode.OK:
        raise typer.Exit(code=result)

    cov = coverage.Coverage()
    cov.load()

    omit: List[str] = [
        "src/example/*",
        "src/db/alembic/*",
        "src\service_meta.py",
        "src\service_template\cli\cli_ehelply_service.py",
        "src\db\__init__.py",
        "src\service.py"
    ]

    # coverage_amount: float = cov.json_report(
    #     omit=omit
    # )

    coverage_amount: float = cov.report(
        show_missing=True,
        omit=omit
    )

    if coverage_amount < COVERAGE_THRESHOLD:
        raise Exception(
            f"Test coverage is {int(coverage_amount)}% which is below {COVERAGE_THRESHOLD}%. Thus, build has failed.")



from ehelply_bootstrapper.integrations.integration import Integration
from ehelply_bootstrapper.utils.state import State
from datetime import datetime
from typing import Union
from ehelply_microservice_library.integrations.fact import get_fact_endpoint
from ehelply_microservice_library.integrations.sdk import SDK

from ehelply_python_sdk.services.notes.sdk import *


class Note(Integration):
    """
    Note integration is used to talk to the ehelply-notes microservice
    """

    def __init__(self) -> None:
        super().__init__("note")

        class IntegratedSDK(NotesSDK):
            def get_base_url(self) -> str:
                return get_fact_endpoint('ehelply-notes')

        self.sdk: IntegratedSDK = IntegratedSDK(
            sdk_configuration=SDK.instance.sdk_configuration,
            requests_session=SDK.instance.requests_session
        )

    def load(self):
        pass
